__author__ = 'pav'
from DataNormalizer.core.log import Bot
from DataNormalizer.utils.helpers import DataLoad, PathSanitizer
from DataNormalizer.utils.web import GetID
from datetime import datetime


class CheckAgent():
    """
        Abstract class for testing & benchmark features
    """
    def __init__(self, *args, **kwargs):
        self.data = kwargs["data_list"]

    def __repr__(self):
        return """
         CheckAgent Object:

            >> data_list: %s
        """ % self.data

    def GPSCheck(self):
        return len(self.data) == len(set([(i[1], i[2]) for i in self.data]))

    def DatetimeCheck(self):
        return len(self.data) == len(set([i[3] for i in self.data]))

    def GPSAutoFix(self):
        gps_all = [(i[1], i[2]) for i in self.data]

        for i in set(gps_all):
            gps_all.remove(i)

        gps_tmp = {(i[1], i[2]): self.data.index(i) for i in self.data}

        for i in gps_all:
            self.data[gps_tmp[i]][1], self.data[gps_tmp[i]][2] = self._GPSOffset(i)

    def _GPSOffset(self, xy):
        return [str(float(i) + float(0.00001)) for i in xy]


class ImageAgent():
    """
        Image object for Info Retrieval Analysis & ReFactoring
    """

    def __init__(self, dir):
        self.Logger = Bot(dir)
        self.region = {
            "id": int(GetID(model="region")) + 1,
            "region": dir.split("\\")[-1],
            "date": datetime.now(),
            "desc": "Not really care for script, admin should edit"
        }
        self.wide_set = None
        self.tele_set = None
        self.check = None

    def ExecAll(self):
        self.ReportDataset()
        self.CorrectDataset()
        self.UIDSetter()
        self.CircleNav()


    def ReportDataset(self):
        self.Logger.Start()
        self.wide_set = DataLoad(file=self.Logger.getImageInfo()[0])
        self.tele_set = DataLoad(file=self.Logger.getImageInfo()[1])

    def CorrectDataset(self):
        self.check = CheckAgent(data_list=self.wide_set)
        self.check.GPSAutoFix()
        self.check = CheckAgent(data_list=self.tele_set)
        self.check.GPSAutoFix()

    def UIDSetter(self):
        id = int(GetID(model="image")) + 1
        for i in self.wide_set:
            i[0] = PathSanitizer(i[0])
            i.append(id)
            i.append("true")
            id += 1

        for i in self.tele_set:
            i[0] = PathSanitizer(i[0])
            i.append(id)
            i.append("false")
            id += 1

    def CircleNav(self):
        for i in self.wide_set:
            i.append(self.wide_set[self.wide_set.index(i)-1][4])
            if self.wide_set.index(i) == len(self.wide_set) - 1:
                i.append(self.wide_set[0][4])
            else:
                i.append(self.wide_set[self.wide_set.index(i)+1][4])

        for i in self.tele_set:
            i.append(self.tele_set[self.tele_set.index(i)-1][4])
            if self.tele_set.index(i) == len(self.tele_set) - 1:
                i.append(self.tele_set[0][4])
            else:
                i.append(self.tele_set[self.tele_set.index(i)+1][4])





if __name__ == "__main__":
    a = ImageAgent("C:\Users\pav\Desktop\Saronikos_15_Spetsopoula")
    a.ExecAll()
    for i in a.region:
        print a.region[i]
    #print a.tele_set